@@ -1,7 +1,6 @@
 package ChainedActionsApp;
 use Moose;
 use namespace::autoclean;
-use TestLogger;
 
 use Catalyst::Runtime 5.80;
 
@@ -17,8 +16,6 @@ __PACKAGE__->config(
   disable_component_regex_fallback => 1,
 );
 
-__PACKAGE__->log(TestLogger->new);
-
 __PACKAGE__->setup;
 
 1;
